# Librería nivel 7mo semestre
# descripción: bla bla bla ...  
# He aquí la librería para solucionar integrales numéricas mediante el método de Monte Carlo. Necesita ingresar la función (en una variable), el intervalo de integración y el número de iteraciones para ejecutar el método de Monte Carlo.

# pip install fbMonteCarlo